| Copyright | Dennis Gosnell 2017 |
|---|---|
| License | BSD3 |
| Maintainer | Dennis Gosnell (cdep.illabout@gmail.com) |
| Stability | experimental |
| Portability | unknown |
| Safe Haskell | None |
| Language | Haskell2010 |
Servant.RawM.Internal.Client
Contents
Description
This module only exports a HasClient instance for RawM.
Documentation
Orphan instances
| HasClient * (RawM' serverType) Source # | Creates a client route like the following:
This allows modification of the underlying Check out the example in the source code repository that shows a more in-depth server, client, and documentation. |